<?php
/**
 * Banner Section options
 *
 * @package Theme Palace
 * @subpackage Pleased Pro
 * @since Pleased Pro 1.0.0
 */

// Add Banner section
$wp_customize->add_section( 'pleased_pro_banner_section', array(
	'title'             => esc_html__( 'Banner','pleased-pro' ),
	'description'       => esc_html__( 'Banner Section options.', 'pleased-pro' ),
	'panel'             => 'pleased_pro_front_page_panel',
) );

// Banner content enable control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[banner_section_enable]', array(
	'default'			=> 	$options['banner_section_enable'],
	'sanitize_callback' => 'pleased_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pleased_Pro_Switch_Control( $wp_customize, 'pleased_pro_theme_options[banner_section_enable]', array(
	'label'             => esc_html__( 'Banner Section Enable', 'pleased-pro' ),
	'section'           => 'pleased_pro_banner_section',
	'on_off_label' 		=> pleased_pro_switch_options(),
) ) );

// Banner content enable control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[banner_search_filter_enable]', array(
	'default'			=> 	$options['banner_search_filter_enable'],
	'sanitize_callback' => 'pleased_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pleased_Pro_Switch_Control( $wp_customize, 'pleased_pro_theme_options[banner_search_filter_enable]', array(
	'label'             => esc_html__( 'Banner Search Filter Enable', 'pleased-pro' ),
	'description'       => sprintf( '%1$s <a href="' . esc_url( admin_url( 'themes.php?page=tgmpa-install-plugins&plugin_status=install' ) ) . '" target="_blank"> %2$s </a> %3$s', esc_html__( 'Show trip search filter from WP Travel plugin. ', 'pleased-pro' ), esc_html__( 'Click Here', 'pleased-pro' ), esc_html__( 'to download.', 'pleased-pro' ) ),
	'section'           => 'pleased_pro_banner_section',
	'on_off_label' 		=> pleased_pro_switch_options(),
	'active_callback' 	=> 'pleased_pro_is_banner_section_enable',
) ) );

// Banner content type control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[banner_content_type]', array(
	'default'          	=> $options['banner_content_type'],
	'sanitize_callback' => 'pleased_pro_sanitize_select',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[banner_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'pleased-pro' ),
	'section'           => 'pleased_pro_banner_section',
	'type'				=> 'select',
	'active_callback' 	=> 'pleased_pro_is_banner_section_enable',
	'choices'			=> pleased_pro_banner_content_type(),
) );

// banner pages drop down chooser control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[banner_content_page]', array(
	'sanitize_callback' => 'pleased_pro_sanitize_page',
) );

$wp_customize->add_control( new Pleased_Pro_Dropdown_Chooser( $wp_customize, 'pleased_pro_theme_options[banner_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'pleased-pro' ),
	'section'           => 'pleased_pro_banner_section',
	'choices'			=> pleased_pro_page_choices(),
	'active_callback'	=> 'pleased_pro_is_banner_section_content_page_enable',
) ) );

// banner posts drop down chooser control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[banner_content_post]', array(
	'sanitize_callback' => 'pleased_pro_sanitize_page',
) );

$wp_customize->add_control( new Pleased_Pro_Dropdown_Chooser( $wp_customize, 'pleased_pro_theme_options[banner_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'pleased-pro' ),
	'section'           => 'pleased_pro_banner_section',
	'choices'			=> pleased_pro_post_choices(),
	'active_callback'	=> 'pleased_pro_is_banner_section_content_post_enable',
) ) );

$wp_customize->add_setting( 'pleased_pro_theme_options[banner_content_trip]', array(
	'sanitize_callback' => 'pleased_pro_sanitize_page',
) );

$wp_customize->add_control( new Pleased_Pro_Dropdown_Chooser( $wp_customize, 'pleased_pro_theme_options[banner_content_trip]', array(
	'label'             => esc_html__( 'Select Trip', 'pleased-pro' ),
	'section'           => 'pleased_pro_banner_section',
	'choices'			=> pleased_pro_trip_choices(),
	'active_callback'	=> 'pleased_pro_is_banner_section_content_trip_enable',
) ) );

// banner title setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[banner_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['banner_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[banner_title]', array(
	'label'           	=> esc_html__( 'Title', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_banner_section',
	'active_callback' 	=> 'pleased_pro_is_banner_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pleased_pro_theme_options[banner_title]', array(
		'selector'            => '#header-featured-image .section-header h2.section-title',
		'settings'            => 'pleased_pro_theme_options[banner_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pleased_pro_banner_title_partial',
    ) );
}

// banner description setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[banner_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['banner_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[banner_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_banner_section',
	'active_callback' 	=> 'pleased_pro_is_banner_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pleased_pro_theme_options[banner_sub_title]', array(
		'selector'            => '#header-featured-image .section-header span.section-subtitle',
		'settings'            => 'pleased_pro_theme_options[banner_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pleased_pro_banner_sub_title_partial',
    ) );
}

// banner image setting and control.
$wp_customize->add_setting( 'pleased_pro_theme_options[banner_image]', array(
	'sanitize_callback' => 'pleased_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pleased_pro_theme_options[banner_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'pleased-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'pleased-pro' ), 717, 520 ),
		'section'     		=> 'pleased_pro_banner_section',
		'active_callback'	=> 'pleased_pro_is_banner_section_content_custom_enable',
) ) );

// banner url setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[banner_video_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[banner_video_url]', array(
	'label'           	=> esc_html__( 'Video URL', 'pleased-pro' ),
	'description'       => esc_html__( 'Note: Input banner url from youtube or media library.', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_banner_section',
	'active_callback' 	=> 'pleased_pro_is_banner_section_enable',
	'type'				=> 'url',
) );